==> brynq_sdk_vplan-0.2.0.tar.gz: brynq_sdk_vplan-0.2.0/brynq_sdk/vplan/__init__.py <==
import requests
import json
from typing import List, Union
from brynq_sdk.brynq import BrynQ
from brynq_sdk.vplan.get_data import GetData
from brynq_sdk.vplan.activity import Activity
from brynq_sdk.vplan.item import Item
from brynq_sdk.vplan.order import Order
from brynq_sdk.vplan.project import Project
from brynq_sdk.vplan.resource import Resource
from brynq_sdk.vplan.time_tracking import TimeTracking
from brynq_sdk.vplan.user import User


class VPlan(BrynQ):
    def __init__(self, label: Union[str, List], debug: bool = False):
        """
        A class to fetch data from the vPlan API. See https://developer.vplan.com/documentation/#tag/General/ for more information
        """
        super().__init__()
        self.headers = self._get_credentials(label)
        self.base_url = 'https://api.vplan.com/v1/'
        self.get = GetData(self)
        self.activity = Activity(self)
        self.item = Item(self)
        self.order = Order(self)
        self.project = Project(self)
        self.resource = Resource(self)
        self.time_tracking = TimeTracking(self)
        self.user = User(self)

    def _get_credentials(self, label) -> str:
        """
        Retrieve API key and env from the system credentials.
        Args: label (Union[str, List]): The label or list of labels to get the credentials.
        Returns: str: The authorization headers
        """
        credentials = self.get_system_credential(system='vplan', label=label)
        headers = {
            'X-Api-Key': credentials['X-Api-Key'],
            'X-Api-Env': credentials['X-Api-Env']
        }
        return headers

==> brynq_sdk_vplan-0.2.1.tar.gz: brynq_sdk_vplan-0.2.1/brynq_sdk/vplan/__init__.py <==
import requests
import json
from typing import List, Union
from brynq_sdk.brynq import BrynQ
from brynq_sdk.vplan.get_data import GetData
from brynq_sdk.vplan.activity import Activity
from brynq_sdk.vplan.item import Item
from brynq_sdk.vplan.order import Order
from brynq_sdk.vplan.project import Project
from brynq_sdk.vplan.resource import Resource
from brynq_sdk.vplan.time_tracking import TimeTracking
from brynq_sdk.vplan.user import User


class VPlan(BrynQ):
    def __init__(self, label: Union[str, List], debug: bool = False):
        """
        A class to fetch data from the vPlan API. See https://developer.vplan.com/documentation/#tag/General/ for more information
        """
        super().__init__()
        self.headers = self._get_credentials(label)
        self.post_headers = {**self.headers, 'Content-Type': 'application/json'}
        self.base_url = 'https://api.vplan.com/v1/'
        self.get = GetData(self)
        self.activity = Activity(self)
        self.item = Item(self)
        self.order = Order(self)
        self.project = Project(self)
        self.resource = Resource(self)
        self.time_tracking = TimeTracking(self)
        self.user = User(self)

    def _get_credentials(self, label) -> dict:
        """
        Retrieve API key and env from the system credentials.
        Args: label (Union[str, List]): The label or list of labels to get the credentials.
        Returns: str: The authorization headers
        """
        credentials = self.get_system_credential(system='vplan', label=label)
        headers = {
            'X-Api-Key': credentials['X-Api-Key'],
            'X-Api-Env': credentials['X-Api-Env']
        }
        return headers
